@@ -1387,6 +1387,8 @@ class emailmgmt {
             $skipped_count = 0;
             $failed_count = 0;
             $imported_accounts = [];
+            $imported_forwarders = [];
+            $skipped_accounts = [];
             $errors = [];
             
             foreach ($response['results'] as $account) {
@@ -1396,6 +1398,10 @@ class emailmgmt {
                     $result = $this->importEmailForwarderFromMailServer($account, $domain_owner);
                     if ($result['status'] === '0') {
                         $imported_count++;
+                        $imported_forwarders[] = $account['address'];
+                    } else if (strpos($result['msg'], 'already exists') !== false) {
+                        $skipped_count++;
+                        $skipped_accounts[] = $account['address'] . ' (forwarder)';
                     } else {
                         $failed_count++;
                         $errors[] = "Forwarder {$account['address']}: " . $result['msg'];
@@ -1415,11 +1421,13 @@ class emailmgmt {
                     $stmt->execute([$account['address']]);
                     if ($stmt->fetch()) {
                         $skipped_count++;
+                        $skipped_accounts[] = $account['address'] . ' (email account)';
                         continue; // Account already exists
                     }
                 } catch (Exception $e) {
                     error_log("Failed to check existing account: " . $e->getMessage());
                     $failed_count++;
+                    $errors[] = "{$account['address']}: Failed to check existing account";
                     continue;
                 }
                 
@@ -1435,8 +1443,33 @@ class emailmgmt {
             }
             
             $message = "Import complete: $imported_count imported, $skipped_count skipped, $failed_count failed";
+            
+            // Add details about what was imported
+            if (!empty($imported_accounts)) {
+                $message .= "\n\nImported email accounts: " . implode(", ", array_slice($imported_accounts, 0, 5));
+                if (count($imported_accounts) > 5) {
+                    $message .= " and " . (count($imported_accounts) - 5) . " more...";
+                }
+            }
+            
+            if (!empty($imported_forwarders)) {
+                $message .= "\n\nImported forwarders: " . implode(", ", array_slice($imported_forwarders, 0, 5));
+                if (count($imported_forwarders) > 5) {
+                    $message .= " and " . (count($imported_forwarders) - 5) . " more...";
+                }
+            }
+            
+            // Add details about what was skipped (if re-running import)
+            if (!empty($skipped_accounts)) {
+                $message .= "\n\nSkipped (already exist): " . implode(", ", array_slice($skipped_accounts, 0, 5));
+                if (count($skipped_accounts) > 5) {
+                    $message .= " and " . (count($skipped_accounts) - 5) . " more...";
+                }
+            }
+            
+            // Add error details
             if (!empty($errors)) {
-                $message .= "\nErrors: " . implode("; ", array_slice($errors, 0, 5));
+                $message .= "\n\nErrors: " . implode("; ", array_slice($errors, 0, 5));
                 if (count($errors) > 5) {
                     $message .= " and " . (count($errors) - 5) . " more...";
                 }
@@ -1445,7 +1478,10 @@ class emailmgmt {
             return [
                 'status' => '0',
                 'msg' => $message,
-                'imported' => $imported_accounts,
+                'imported' => array_merge($imported_accounts, $imported_forwarders),
+                'imported_accounts' => $imported_accounts,
+                'imported_forwarders' => $imported_forwarders,
+                'skipped' => $skipped_accounts,
                 'imported_count' => $imported_count,
                 'skipped_count' => $skipped_count,
                 'failed_count' => $failed_count
@@ -1510,20 +1546,48 @@ class emailmgmt {
      */
     private function importEmailForwarderFromMailServer($forwarder, $username) {
         try {
-            // Check if forwarder already exists
-            $stmt = $this->db->prepare("SELECT id FROM whp.email_forwarders WHERE source_email = ?");
-            $stmt->execute([$forwarder['address']]);
-            if ($stmt->fetch()) {
-                return ['status' => '1', 'msg' => 'Forwarder already exists'];
-            }
+            $imported_destinations = 0;
+            $skipped_destinations = 0;
             
             // Import each redirect_to address
             foreach ($forwarder['redirect_to'] as $destination) {
+                // Check if this specific forwarder rule already exists
                 $stmt = $this->db->prepare("
-                    INSERT INTO whp.email_forwarders 
-                    (source_email, destination_email, destination_type, username, active, created_at, updated_at)
-                    VALUES (?, ?, 'external', ?, ?, NOW(), NOW())
+                    SELECT id FROM whp.email_forwarders 
+                    WHERE source_email = ? AND destination_email = ?
                 ");
+                $stmt->execute([$forwarder['address'], $destination]);
+                
+                if ($stmt->fetch()) {
+                    $skipped_destinations++;
+                    continue; // Skip this destination, it already exists
+                }
+                
+                // Check if the table has destination_type column
+                $stmt = $this->db->prepare("
+                    SELECT COLUMN_NAME 
+                    FROM INFORMATION_SCHEMA.COLUMNS 
+                    WHERE TABLE_SCHEMA = 'whp' 
+                    AND TABLE_NAME = 'email_forwarders' 
+                    AND COLUMN_NAME = 'destination_type'
+                ");
+                $stmt->execute();
+                $has_destination_type = $stmt->fetch() !== false;
+                
+                // Build the insert query based on table structure
+                if ($has_destination_type) {
+                    $stmt = $this->db->prepare("
+                        INSERT INTO whp.email_forwarders 
+                        (source_email, destination_email, destination_type, username, active, created_at, updated_at)
+                        VALUES (?, ?, 'email', ?, ?, NOW(), NOW())
+                    ");
+                } else {
+                    $stmt = $this->db->prepare("
+                        INSERT INTO whp.email_forwarders 
+                        (source_email, destination_email, username, active, created_at, updated_at)
+                        VALUES (?, ?, ?, ?, NOW(), NOW())
+                    ");
+                }
                 
                 $stmt->execute([
                     $forwarder['address'],
@@ -1531,9 +1595,17 @@ class emailmgmt {
                     $username,
                     !$forwarder['disabled']
                 ]);
+                
+                $imported_destinations++;
             }
             
-            return ['status' => '0', 'msg' => 'Forwarder imported successfully'];
+            if ($imported_destinations > 0) {
+                return ['status' => '0', 'msg' => "Forwarder imported successfully ({$imported_destinations} destinations)"];
+            } else if ($skipped_destinations > 0) {
+                return ['status' => '1', 'msg' => 'Forwarder already exists'];
+            } else {
+                return ['status' => '1', 'msg' => 'No destinations to import'];
+            }
             
         } catch (Exception $e) {
             error_log("Failed to import forwarder {$forwarder['address']}: " . $e->getMessage());
